@@ -52,14 +52,23 @@
 #  define JIT_RET		_RAX
 #  if __WORDSIZE == 32
 #    define JIT_FRET		_ST0
+typedef jit_uint32_t		jit_regset_t;
 #  else
+#    define JIT_RA0		_RDI
+#    define JIT_FA0		_XMM0
 #    define JIT_FRET		_XMM0
+typedef jit_uint64_t		jit_regset_t;
 #  endif
 #elif defined(__mips__)
+#  define JIT_RA0		_A0
+#  define JIT_FA0		_F12
 #  define JIT_SP		_SP
 #  define JIT_RET		_V0
 #  define JIT_FRET		_F0
+typedef jit_uint64_t		jit_regset_t;
 #elif defined(__arm__)
+#  define JIT_RA0		_R0
+#  define JIT_FA0		_D0
 #  define JIT_SP		_R13
 #  define JIT_RET		_R0
 #  if defined(__ARM_PCS_VFP)
@@ -67,30 +76,51 @@
 #  else
 #    define JIT_FRET		_R0
 #  endif
+typedef jit_uint64_t		jit_regset_t;
 #elif defined(__ppc__) || defined(__powerpc__)
+#  define JIT_RA0		_R3
+#  define JIT_FA0		_F1
 #  define JIT_SP		_R1
 #  define JIT_RET		_R3
 #  define JIT_FRET		_F1
+typedef jit_uint64_t		jit_regset_t;
 #elif defined(__sparc__)
 #  define JIT_SP		_SP
 #  define JIT_RET		_I0
 #  define JIT_FRET		_F0
+typedef jit_uint64_t		jit_regset_t;
 #elif defined(__ia64__)
 #  define JIT_SP		_R12
 #  define JIT_RET		_R8
 #  define JIT_FRET		_F8
+typedef struct {
+    jit_uint64_t	rl;
+    jit_uint64_t	rh;
+    jit_uint64_t	fl;
+    jit_uint64_t	fh;
+} jit_regset_t;
 #elif defined(__hppa__)
 #  define JIT_SP		_R30
 #  define JIT_RET		_R28
 #  define JIT_FRET		_F4
+typedef jit_uint64_t		jit_regset_t;
 #elif defined(__aarch64__)
+#  define JIT_RA0		_R0
+#  define JIT_FA0		_V0
 #  define JIT_SP		_SP
 #  define JIT_RET		_R0
 #  define JIT_FRET		_V0
+typedef jit_uint64_t		jit_regset_t;
 #elif defined(__s390x__)
 #  define JIT_SP		_R15
 #  define JIT_RET		_R2
 #  define JIT_FRET		_F0
+typedef jit_uint32_t		jit_regset_t;
+#elif defined(__alpha__)
+#  define JIT_SP		_SP
+#  define JIT_RET		_V0
+#  define JIT_FRET		_F0
+typedef jit_uint64_t		jit_regset_t;
 #endif
 
 #define jit_size(vector)	(sizeof(vector) / sizeof((vector)[0]))
@@ -330,7 +360,7 @@ struct jit_compiler {
     jit_int32_t		  rout;		/* first output register */
     jit_int32_t		  breg;		/* base register for prolog/epilog */
 #endif
-#if __mips__ || __ia64__
+#if __mips__ || __ia64__ || __alpha__
     jit_int32_t		  carry;
 #define jit_carry	  _jitc->carry
 #endif
@@ -557,7 +587,7 @@ _emit_ldxi_d(jit_state_t*, jit_int32_t, jit_int32_t, jit_word_t);
 extern void
 _emit_stxi_d(jit_state_t*, jit_word_t, jit_int32_t, jit_int32_t);
 
-extern void jit_init_debug(void);
+extern void jit_init_debug(char*);
 extern void jit_finish_debug(void);
 
 extern void jit_init_note(void);
@@ -567,6 +597,8 @@ extern void _jit_set_note(jit_state_t*, jit_note_t*, char*, int, jit_int32_t);
 #define jit_annotate()		_jit_annotate(_jit)
 extern void _jit_annotate(jit_state_t*);
 
+extern jit_pointer_t jit_memcpy(jit_pointer_t,jit_pointer_t,jit_word_t);
+extern jit_pointer_t jit_memmove(jit_pointer_t,jit_pointer_t,jit_word_t);
 extern void jit_alloc(jit_pointer_t*, jit_word_t);
 extern void jit_realloc(jit_pointer_t*, jit_word_t, jit_word_t);
 void jit_free(jit_pointer_t*);
@@ -595,6 +627,5 @@ jit_get_max_instr(void);
  * Externs
  */
 extern jit_register_t	 _rvs[];
-extern const char	*jit_progname;
 
 #endif /* _jit_private_h */
