@@ -57,12 +57,12 @@ static jit_state_t		 *disasm_jit;
  * Implementation
  */
 void
-jit_init_debug(void)
+jit_init_debug(char *progname)
 {
 #if DISASSEMBLER
     bfd_init();
 
-    disasm_bfd = bfd_openr(jit_progname, NULL);
+    disasm_bfd = bfd_openr(progname, NULL);
     assert(disasm_bfd);
     bfd_check_format(disasm_bfd, bfd_object);
     bfd_check_format(disasm_bfd, bfd_archive);
@@ -100,6 +100,10 @@ jit_init_debug(void)
     disasm_info.mach = bfd_mach_s390_64;
     disasm_info.endian = disasm_info.display_endian = BFD_ENDIAN_BIG;
     disasm_info.disassembler_options = "zarch";
+#  endif
+#  if defined(__alpha__)
+    disasm_info.arch = bfd_arch_alpha;
+    disasm_info.mach = bfd_mach_alpha_ev6;
 #  endif
     disasm_info.print_address_func = disasm_print_address;
 
@@ -117,7 +121,13 @@ jit_init_debug(void)
 
 	    if (bfd_get_file_flags(disasm_bfd) & DYNAMIC) {
 		dyn_storage = bfd_get_dynamic_symtab_upper_bound(disasm_bfd);
+#  if defined(__alpha__)
+		/* XXX */
+		if (dyn_storage < 0)
+		    dyn_storage = 0;
+#  else
 		assert(dyn_storage >= 0);
+#  endif
 	    }
 	    else
 		dyn_storage = 0;
