@@ -170,7 +170,6 @@ _patch_register(jit_state_t *jit, jit_node_t *node, jit_node_t *link,
 /*
  * Initialization
  */
-const char	*jit_progname;
 #if !defined(__sgi)
 #define  mmap_fd			-1
 #endif
@@ -181,9 +180,8 @@ const char	*jit_progname;
 void
 init_jit(char *progname)
 {
-    jit_progname = progname;
     jit_get_cpu();
-    jit_init_debug();
+    jit_init_debug(progname);
     jit_init_size();
 }
 
@@ -238,7 +236,7 @@ _jit_get_reg(jit_state_t *_jit, jit_int32_t regspec)
 		!jit_regset_tstbit(&_jitc->regarg, regno) &&
 		!(regspec & jit_class_nospill)) {
 	    spill:
-		assert(_jitc->function);
+		assert(_jitc->function != NULL);
 		if (spec & jit_class_gpr) {
 		    if (!_jitc->function->regoff[regno]) {
 			_jitc->function->regoff[regno] =
@@ -277,7 +275,7 @@ _jit_get_reg(jit_state_t *_jit, jit_int32_t regspec)
 		if (jit_class(_rvs[regno].spec) & jit_class_sav) {
 		    /* if will modify callee save registers without a
 		     * function prolog, better patch this assertion */
-		    assert(_jitc->function);
+		    assert(_jitc->function != NULL);
 		    if (!jit_regset_tstbit(&_jitc->function->regset, regno)) {
 			jit_regset_setbit(&_jitc->function->regset, regno);
 			_jitc->again = 1;
@@ -332,7 +330,7 @@ _jit_unget_reg(jit_state_t *_jit, jit_int32_t regno)
 	    jit_load(regno);
 	jit_regset_clrbit(&_jitc->regsav, regno);
     }
-    assert(jit_regset_tstbit(&_jitc->regarg, regno));
+    assert(jit_regset_tstbit(&_jitc->regarg, regno) != 0);
     jit_regset_clrbit(&_jitc->regarg, regno);
 }
 
@@ -529,7 +527,7 @@ _jit_load(jit_state_t *_jit, jit_int32_t reg)
 
     reg = jit_regno(reg);
     assert(!_jitc->realize);
-    assert(_jitc->spill[reg]);
+    assert(_jitc->spill[reg] != NULL);
     node = jit_new_node_w(jit_code_load, reg);
     /* create a path to flag the save/load is not required */
     node->link = _jitc->spill[reg];
@@ -551,11 +549,11 @@ jit_pointer_t
 _jit_address(jit_state_t *_jit, jit_node_t *node)
 {
     assert(_jitc->done);
-    assert(node &&
+    assert(node != NULL &&
 	   /* If a node type that is documented to be a fixed marker */
 	   (node->code == jit_code_note || node->code == jit_code_name ||
 	    /* If another special fixed marker, returned by jit_indirect() */
-	    (node->code == jit_code_label && (node->flag & jit_flag_use))));
+	    (node->code == jit_code_label && (node->flag & jit_flag_use) != 0)));
     return ((jit_pointer_t)node->u.w);
 }
 
@@ -612,7 +610,7 @@ _jit_data(jit_state_t *_jit, jit_pointer_t data,
 	}
 	node->u.w = _jitc->data.offset;
 	node->v.w = length;
-	memcpy(_jitc->data.ptr + _jitc->data.offset, data, length);
+	jit_memcpy(_jitc->data.ptr + _jitc->data.offset, data, length);
 	_jitc->data.offset += length;
 
 	node->next = _jitc->data.table[key];
@@ -1132,7 +1130,7 @@ _jit_link(jit_state_t *_jit, jit_node_t *node)
 void
 _jit_prepare(jit_state_t *_jit)
 {
-    assert(_jitc->function);
+    assert(_jitc->function != NULL);
     _jitc->function->call.call = jit_call_default;
     _jitc->function->call.argi =
 	_jitc->function->call.argf =
@@ -1154,11 +1152,11 @@ void
 _jit_ellipsis(jit_state_t *_jit)
 {
     if (_jitc->prepare) {
-	assert(!_jitc->function->call.call & jit_call_varargs);
+	assert(!(_jitc->function->call.call & jit_call_varargs));
 	_jitc->function->call.call |= jit_call_varargs;
     }
     else {
-	assert(!_jitc->function->self.call & jit_call_varargs);
+	assert(!(_jitc->function->self.call & jit_call_varargs));
 	_jitc->function->self.call |= jit_call_varargs;
     }
 }
@@ -1724,9 +1722,12 @@ _jit_dataset(jit_state_t *_jit)
     }
 
     if (!_jitc->no_data)
-	memcpy(_jit->data.ptr, _jitc->data.ptr, _jitc->data.offset);
+	jit_memcpy(_jit->data.ptr, _jitc->data.ptr, _jitc->data.offset);
 
     if (_jitc->no_note) {
+	/* Space for one note is always allocated, so revert it here
+	 * if after jit_new_state was called, it is also requested to
+	 * not generate annotation information */
 	_jit->note.length = 0;
 	_jitc->note.size = 0;
     }
@@ -2028,9 +2029,27 @@ _jit_update(jit_state_t *_jit, jit_node_t *node,
 		    jit_regset_and(mask, mask, &ztmp);
 		}
 		break;
-	    case jit_code_prolog:	case jit_code_epilog:
+	    case jit_code_prolog:
 		jit_regset_set_ui(mask, 0);
 		return;
+	    case jit_code_epilog:
+		jit_regset_set_ui(mask, 0);
+#if defined(JIT_RET)
+		/* On some backends it may be required to allocate one
+		 * or more registers to jump from a jit_ret* to the
+		 * epilog label.
+		 * Because currently there is no type information,
+		 * assume JIT_RET and JIT_FRET are live in the epilog.
+		 * Only JIT_RET really should be marked as live, to
+		 * prevent it being allocated, usually in the jump to
+		 * the epilog, but also mark JIT_FRET as live for the
+		 * sake of correctness. */
+		jit_regset_setbit(live, JIT_RET);
+#endif
+#if defined(JIT_FRET)
+		jit_regset_setbit(live, JIT_FRET);
+#endif
+		return;
 	    case jit_code_callr:
 		value = jit_regno(node->u.w);
 		if (!(node->u.w & jit_regno_patch)) {
@@ -2042,19 +2061,19 @@ _jit_update(jit_state_t *_jit, jit_node_t *node,
 	    case jit_code_calli:
 #if defined(JIT_RET)
 		if (jit_regset_tstbit(mask, JIT_RET)) {
-		    jit_regset_setbit(&_jitc->reglive, JIT_RET);
+		    jit_regset_setbit(live, JIT_RET);
 		    jit_regset_clrbit(mask, JIT_RET);
 		}
 #  if __arm__
 		if (jit_regset_tstbit(mask, _R1)) {
-		    jit_regset_setbit(&_jitc->reglive, _R1);
+		    jit_regset_setbit(live, _R1);
 		    jit_regset_clrbit(mask, _R1);
 		}
 #  endif
 #endif
 #if defined(JIT_FRET)
 		if (jit_regset_tstbit(mask, JIT_FRET)) {
-		    jit_regset_setbit(&_jitc->reglive, JIT_FRET);
+		    jit_regset_setbit(live, JIT_FRET);
 		    jit_regset_clrbit(mask, JIT_FRET);
 		}
 #endif
@@ -2583,7 +2602,7 @@ _simplify_movr(jit_state_t *_jit, jit_node_t *prev, jit_node_t *node,
 	return (1);
     }
     if (_jitc->values[right].kind == jit_kind_word)
-	memcpy(value, _jitc->values + right, sizeof(jit_value_t));
+	jit_memcpy(value, _jitc->values + right, sizeof(jit_value_t));
     else {
 	value->kind = jit_kind_register;
 	value->base.q.l = right;
@@ -2632,14 +2651,14 @@ _simplify_movi(jit_state_t *_jit, jit_node_t *prev, jit_node_t *node,
 		else
 		    node->code = jit_code_movr_d;
 		node->v.w = offset;
-		memcpy(value, _jitc->values + offset, sizeof(jit_value_t));
+		jit_memcpy(value, _jitc->values + offset, sizeof(jit_value_t));
 		++_jitc->gen[regno];
 		return (0);
 	    }
 	}
     }
     value->kind = kind;
-    memcpy(&value->base.w, &node->v.w, size);
+    jit_memcpy(&value->base.w, &node->v.w, size);
     ++_jitc->gen[regno];
 
     return (0);
@@ -3094,4 +3113,6 @@ _patch_register(jit_state_t *_jit, jit_node_t *node, jit_node_t *link,
 #  include "jit_aarch64.c"
 #elif defined(__s390x__)
 #  include "jit_s390x.c"
+#elif defined(__alpha__)
+#  include "jit_alpha.c"
 #endif
